This is the example of silicon calculation. The Wien2k calculation was made to
obtain forces with 2x2x2 k-point mesh for the supercell, PBE, and the lattice
parameters in Si.struct.

`phono3py_disp.yaml` is generated by

```
% phono3py --wien2k -d --dim 2 2 2 -c Si.struct
```

To create `fc3.hdf5` and `fc2.hdf5`,

```
% phono3py-load
```

Using 11x11x11 sampling mesh, lattice thermal conductivity is calculated by

```
% phono3py-load --mesh 11 11 11 --br --ts 300
```

`kappa-m111111.hdf5` is written as the result. The lattice thermal conductivity
is calculated as 119.1 W/m-K at 300 K. This becomes, with 19x19x19 sampling
mesh, 128.1 W/m-K.

The .scf files for supercells are found in `Si1_structS_scf.tar.xz`. If phono3py
is properly installed, the following command should work.

```
% phono3py --cf3 Si1_structS_scf/Si1.structS-{00001..00111}.scf
```
